@@ -208,7 +208,7 @@ def RepoCheck():
         exit()
 
     allModified = modifiedStaged + modifiedUnstaged
-    untrackedSrc = [n for n in repo.untracked_files if n.split('/')[1:] in os.listdir(sourceDir)]
+    untrackedSrc = [n for n in repo.untracked_files if n.split('/')[0] == sourceDir]
     return [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
 #--------------------------------
@@ -281,7 +281,7 @@ def diff():
         for i in range(len(fls)):
             reqs += fls[i][0]
             chars += fls[i][1]
-        estimatedT = int(reqs * 1.1)
+        estimatedT = int(reqs * 1.3)
         print('\n Target languages:\t\t\t' + ', '.join(targetLangs))
         print(' Total of calls to translation service:\t' + str(reqs))
         print(' Total of characters for translation:\t' + str(chars * len(targetLangs)))
@@ -383,7 +383,7 @@ def all():
             for i in range(len(fls)):
                 reqs += fls[i][0]
                 chars += fls[i][1]
-            estimatedT = int(reqs * 1.1)
+            estimatedT = int(reqs * 1.3)
             print(' Total of source language characters:\t' + str(chars))
             print(' Total of files to be generated:\t' + str(nFls))
             print(' Total of calls to translation service:\t' + str(reqs))
